@@ -1,4 +1,6 @@
 from .services import (
+    UniversesService,
+    CargoBaysService,
     JobsService,
     LogService,
     LzService,
