@@ -1,6 +1,8 @@
+from .universes import UniversesService
+from .cargobays import CargoBaysService
 from .jobs import JobsService
 from .log import LogService
 from .lz import LzService
 from .missions import MissionsService
 from .profiles import ProfilesService
-from .stations import StationsService
+from .stations import StationsService
\ No newline at end of file
