@@ -4,6 +4,8 @@ if sys.version_info[0] == 3:
     from .events import GalileoConnector
 
 from .repositories import (
+    UniversesRepository,
+    CargoBaysRepository,
     JobsRepository,
     LzRepository,
     ProfilesRepository,
