@@ -155,12 +155,16 @@ def job_dict_to_job(job):
         datetime.fromtimestamp(job["time_created"]),
         datetime.fromtimestamp(job["last_updated"]),
         job["status"],
-        job["container"],
+        job["cpu_count"],
+        job["gpu_count"],
+        job["memory_amount"],
+        job["enable_tunnel"],
+        job["tunnel_port"],
+        job["tunnel_url"],
         job["name"],
         job["stationid"],
         job["userid"],
         job["state"],
-        job["oaid"],
         job["pay_status"],
         job["pay_interval"],
         job["total_runtime"],
